#!/usr/bin/env python
#-*- coding: utf-8 -*-
"""
smash.cli
~~~~~~~~~

Cli interface for Smash.
"""

import os
import sys
import argparse
from smash.core import Smash
from smash.utils import Colors


def init_args_parser():

    parser = argparse.ArgumentParser()

    parser.add_argument("-p", "--preview", action="store_true",
        help="display a preview of the directory tree")

    parser.add_argument("-v", "--verbose", action="store_true",
        help="show which folder has been created and which not")

    parser.add_argument("--movements",
        help="to use your custom movements characters")

    parser.add_argument("--colors", choices=('auto'), 
        help="allow colored output")  

    parser.add_argument("directories",
        help="the string made up of the directories you want to be created")

    return parser


def main():
    """Entry point for Smash"""

    s = Smash()
    colors = Colors()

    parser = init_args_parser()
    args = parser.parse_args()

    if args.movements:
        success = s.set_custom_mov(args.movements.strip(' ,'))
        if not success:
            print("Bad input for the --movements= option. Take a look at the"
                  "documentation for the correct format.")
            sys.exit(0)

    if args.colors == 'auto':
        colors.enable_colors()      
        
    if args.preview:
        try:
            s.print_dirtree(os.getcwd(), args.directories, colors)
        except ValueError as e:
            print("Bad argument. Take a look at the documentation for the "
                  "correct string format.")
            sys.exit(0)
    else:
        try:
            done, not_done = s.make_dirtree(os.getcwd(), args.directories)
        except ValueError:
            print("Bad argument. Take a look at the documentation for the "
                  "correct string format")
            sys.exit(0)   
        else:
            if not args.verbose:
                done_str = "%d directories created" % len(done)
                if not_done:
                    not_done_str = (" ..%d directories cannot be created"
                                       % len(not_done))
                else:
                    not_done_str = ""

                print(colors.green + done_str + 
                      colors.red + not_done_str + 
                      colors.default)
            else:

                print(colors.green + 
                      "%d directories successfully created!" % (len(done)) + 
                      colors.default)
                for p in done:
                    print(" - " +p)

                if not_done:
                    print(colors.red +   
                          "%d directories cannot be created or already exist!" 
                          % (len(not_done)) + colors.default)
                    for p in not_done:
                        print(" - " + p)
